"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchEntityConfiguration = void 0;
const verifyJsonWebToken_1 = require("../jsonWeb/verifyJsonWebToken");
const utils_1 = require("../utils");
const validate_1 = require("../utils/validate");
const entityConfigurationJwt_1 = require("./entityConfigurationJwt");
/**
 *
 * {@link https://openid.net/specs/openid-federation-1_0.html#section-9.1 | Federation Entity Request}
 *
 */
const fetchEntityConfiguration = (_a) => __awaiter(void 0, [_a], void 0, function* ({ entityId, verifyJwtCallback }) {
    // Create the entity URL
    const federationUrl = (0, utils_1.addPaths)(entityId, '.well-known', 'openid-federation');
    // Fetch the JWT entity configuration
    const entityConfigurationJwt = yield utils_1.fetcher.get({
        url: federationUrl,
        requiredContentType: 'application/entity-statement+jwt',
    });
    // Parse the JWT into its claims
    const { claims } = (0, validate_1.validate)({
        schema: entityConfigurationJwt_1.entityConfigurationJwtSchema,
        data: entityConfigurationJwt,
        errorMessage: 'fetched entity configuration JWT is invalid',
    });
    yield (0, verifyJsonWebToken_1.verifyJwtSignature)({ jwt: entityConfigurationJwt, verifyJwtCallback });
    return claims;
});
exports.fetchEntityConfiguration = fetchEntityConfiguration;
//# sourceMappingURL=fetchEntityConfiguration.js.map