"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchEntityConfigurationChains = void 0;
const ErrorCode_1 = require("../error/ErrorCode");
const OpenIdFederationError_1 = require("../error/OpenIdFederationError");
const fetchEntityConfiguration_1 = require("./fetchEntityConfiguration");
/**
 *
 * Fetch an entity configuration chain until one of the trust anchors is hit (per chain)
 *
 * returns a list of chains (a list of lists of entity configurations)
 *
 */
const fetchEntityConfigurationChains = (options) => __awaiter(void 0, void 0, void 0, function* () {
    if (options.trustAnchorEntityIds.length === 0) {
        throw new OpenIdFederationError_1.OpenIdFederationError(ErrorCode_1.ErrorCode.Validation, 'Cannot establish a configuration chain for zero trust anchors');
    }
    // inner function so we can expose a more user-friendly API
    const __fetchEntityConfigurationChains = (currentEntityId_1, ...args_1) => __awaiter(void 0, [currentEntityId_1, ...args_1], void 0, function* (currentEntityId, path = []) {
        // Fetch the entity configuration of the current entity id
        const configuration = yield (0, fetchEntityConfiguration_1.fetchEntityConfiguration)({
            verifyJwtCallback: options.verifyJwtCallback,
            entityId: currentEntityId,
        });
        // Append the configuration to the visited paths
        const localPath = [...path, configuration];
        const allPaths = [];
        // Found a trust anchor
        if (options.trustAnchorEntityIds.includes(configuration.sub)) {
            allPaths.push(localPath);
        }
        // Fetch the superior entity configurations
        if (configuration.authority_hints) {
            const promises = [];
            for (const superior of configuration.authority_hints) {
                // Do not fetch superiors we already have in the local map to avoid loops
                if (localPath.map((v) => v.sub).includes(superior))
                    continue;
                // Recursively fetch the entity chains
                promises.push(__fetchEntityConfigurationChains(superior, localPath));
            }
            const results = yield Promise.allSettled(promises);
            for (const res of results) {
                if (res.status === 'fulfilled') {
                    allPaths.push(...res.value);
                }
            }
        }
        // Return a list of chains
        return allPaths;
    });
    return __fetchEntityConfigurationChains(options.leafEntityId);
});
exports.fetchEntityConfigurationChains = fetchEntityConfigurationChains;
//# sourceMappingURL=fetchEntityConfigurationChains.js.map