"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUsedJsonWebKey = void 0;
const zod_1 = require("zod");
const validate_1 = require("../utils/validate");
const jsonWebKeySet_1 = require("./jsonWebKeySet");
const getUsedJsonWebKey = (header, claims) => {
    var _a;
    const validatedHeader = (0, validate_1.validate)({
        schema: zod_1.z
            .object({
            kid: zod_1.z.string(),
        })
            .passthrough(),
        data: header,
        errorMessage: 'invalid header claims. Should contain a key id',
    });
    const validatedClaims = (0, validate_1.validate)({
        schema: zod_1.z.object({ jwks: jsonWebKeySet_1.jsonWebKeySetSchema }).passthrough(),
        data: claims,
        errorMessage: 'Invalid payload claims. Should contain a json web key set',
    });
    // Get the key from the `claims.jwks` by the `header.kid`
    const key = (_a = validatedClaims.jwks) === null || _a === void 0 ? void 0 : _a.keys.find((key) => key.kid === validatedHeader.kid);
    if (!key) {
        throw new Error(`key with id: '${header.kid}' could not be found in the claims`);
    }
    return key;
};
exports.getUsedJsonWebKey = getUsedJsonWebKey;
//# sourceMappingURL=getUsedJsonWebKey.js.map