"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonWebTokenSchema = void 0;
const buffer_1 = require("buffer");
const zod_1 = require("zod");
const validate_1 = require("../utils/validate");
const defaultSchema = zod_1.z.record(zod_1.z.string().or(zod_1.z.number()), zod_1.z.unknown());
/**
 *
 * @todo better jwt validation
 *
 */
const jsonWebTokenSchema = ({ claimsSchema = defaultSchema, headerSchema = defaultSchema, } = {
    claimsSchema: defaultSchema,
    headerSchema: defaultSchema,
}) => zod_1.z.string().transform((s, ctx) => {
    const [header, claims, signature] = s.split('.');
    if (!header) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.custom,
            message: 'JWT does not contain a header parameter',
        });
        return zod_1.z.NEVER;
    }
    if (!claims) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.custom,
            message: 'JWT does not contain a payload',
        });
        return zod_1.z.NEVER;
    }
    if (!signature) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.custom,
            message: 'JWT does not contain a signature',
        });
        return zod_1.z.NEVER;
    }
    const decodedHeader = buffer_1.Buffer.from(header, 'base64url').toString();
    const decodedClaims = buffer_1.Buffer.from(claims, 'base64url').toString();
    const decodedSignature = buffer_1.Buffer.from(signature, 'base64url');
    const validatedHeader = (0, validate_1.validate)({
        schema: headerSchema,
        data: JSON.parse(decodedHeader),
        errorMessage: 'invalid header claims provided',
    });
    const validatedClaims = (0, validate_1.validate)({
        schema: claimsSchema,
        data: JSON.parse(decodedClaims),
        errorMessage: 'invalid payload claims provided',
    });
    return {
        header: validatedHeader,
        claims: validatedClaims,
        signature: new Uint8Array(decodedSignature),
    };
});
exports.jsonWebTokenSchema = jsonWebTokenSchema;
//# sourceMappingURL=jsonWebToken.js.map