import { z } from 'zod';
export declare const trustMarkClaimsSchema: z.ZodObject<{
    iss: z.ZodString;
    sub: z.ZodString;
    id: z.ZodString;
    iat: z.ZodEffects<z.ZodUnion<[z.ZodDate, z.ZodNumber, z.ZodEffects<z.ZodString, number | Date, string>]>, Date, string | number | Date>;
    exp: z.ZodOptional<z.ZodEffects<z.ZodUnion<[z.ZodDate, z.ZodNumber, z.ZodEffects<z.ZodString, number | Date, string>]>, Date, string | number | Date>>;
    ref: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    sub: string;
    iss: string;
    id: string;
    iat: Date;
    exp?: Date | undefined;
    ref?: string | undefined;
}, {
    sub: string;
    iss: string;
    id: string;
    iat: string | number | Date;
    exp?: string | number | Date | undefined;
    ref?: string | undefined;
}>;
export declare const trustMarkSchema: z.ZodObject<{
    id: z.ZodString;
    trust_mark: z.ZodEffects<z.ZodString, {
        header: Record<string | number, unknown>;
        claims: {
            sub: string;
            iss: string;
            id: string;
            iat: Date;
            exp?: Date | undefined;
            ref?: string | undefined;
        };
        signature: Uint8Array;
    }, string>;
}, "strip", z.ZodTypeAny, {
    id: string;
    trust_mark: {
        header: Record<string | number, unknown>;
        claims: {
            sub: string;
            iss: string;
            id: string;
            iat: Date;
            exp?: Date | undefined;
            ref?: string | undefined;
        };
        signature: Uint8Array;
    };
}, {
    id: string;
    trust_mark: string;
}>;
export type TrustMark = z.output<typeof trustMarkSchema>;
